-- Use // mod.db.profile // to interact with other options within the module
-- Use // HideBlizzard.db.profile.modules // to interact with main options

local mod = HideBlizzard:NewModule('Target', 'AceEvent-3.0')
mod.modName = 'Target'

local options = {
	combopointframe = {
		type = 'toggle',
		name = 'Combo Point Frame',
		width = 'full',
		get = function() return mod.db.profile.combopointframe end,
		set = function(info, v)
			mod.db.profile.combopointframe = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Target end,
	},
	focusframe = {
		type = 'toggle',
		name = 'Focus Frame',
		width = 'full',
		get = function() return mod.db.profile.focusframe end,
		set = function(info, v)
			mod.db.profile.focusframe = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Target end,
	},
	targetunitframe = {
		type = 'toggle',
		name = 'Target Unit Frame',
		width = 'full',
		get = function() return mod.db.profile.targetunitframe end,
		set = function(info, v)
			mod.db.profile.targetunitframe = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Target end,
	},
}

local defaults = {
	profile = {
		['*'] = false,
	},
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Target', defaults)
end

function mod:OnEnable()
	mod:UpdateFrames()
end

function mod:OnDisable()
	mod:UpdateFrames()
end

function mod:UpdateFrames()
	if mod.db.profile.combopointframe == true and HideBlizzard.db.profile.modules.Target == true then
		local _, class = UnitClass('player')
		if (class == 'ROGUE') or (class =='DRUID') then
			for i = 1, MAX_COMBO_POINTS do
				local combopointframe = _G['ComboPoint'..i]
				combopointframe:Hide()
				combopointframe:UnregisterAllEvents()
				combopointframe.Show = function() end
			end
		end
	else
		local _, class = UnitClass('player')
		if (class == 'ROGUE') or (class == 'DRUID') then
			for i = 1, MAX_COMBO_POINTS do
				local combopointframe = _G['ComboPoint'..i]
				combopointframe.Show = nil
				combopointframe:Show()
				combopointframe:RegisterEvent('PLAYER_FOCUS_CHANGED')
				combopointframe:RegisterEvent('PLAYER_TARGET_CHANGED')
				combopointframe:RegisterEvent('PLAYER_COMBO_POINTS')
				ComboFrame_Update()
			end
		end
	end
	if mod.db.profile.focusframe == true and HideBlizzard.db.profile.modules.Target == true then
		FocusFrame:UnregisterAllEvents()
		FocusFrame:Hide()
	else
		if UnitExists('focus') then
			FocusFrame:Show()
		end
		FocusFrame:RegisterEvent('PLAYER_TARGET_CHANGED')
		FocusFrame:RegisterEvent('PLAYER_FOCUS_CHANGED')
		FocusFrame:RegisterEvent('UNIT_HEALTH')
		FocusFrame:RegisterEvent('UNIT_LEVEL')
		FocusFrame:RegisterEvent('UNIT_FACTION')
		FocusFrame:RegisterEvent('UNIT_CLASSIFICATION_CHANGED')
		FocusFrame:RegisterEvent('UNIT_AURA')
		FocusFrame:RegisterEvent('PLAYER_FLAGS_CHANGED')
		FocusFrame:RegisterEvent('PARTY_MEMBERS_CHANGED')
		FocusFrame_Update(FocusFrame)
	end
	if mod.db.profile.targetunitframe == true and HideBlizzard.db.profile.modules.Target == true then
		TargetFrame:UnregisterAllEvents()
		TargetFrame:Hide()
	else
		if UnitExists('target') then
			TargetFrame:Show()
		end
		TargetFrame:RegisterEvent('PLAYER_TARGET_CHANGED')
		TargetFrame:RegisterEvent('PLAYER_FOCUS_CHANGED')
		TargetFrame:RegisterEvent('UNIT_HEALTH')
		TargetFrame:RegisterEvent('UNIT_LEVEL')
		TargetFrame:RegisterEvent('UNIT_FACTION')
		TargetFrame:RegisterEvent('UNIT_CLASSIFICATION_CHANGED')
		TargetFrame:RegisterEvent('UNIT_AURA')
		TargetFrame:RegisterEvent('PLAYER_FLAGS_CHANGED')
		TargetFrame:RegisterEvent('PARTY_MEMBERS_CHANGED')
		TargetFrame_Update(TargetFrame)
	end
end

function mod:Info()
	return 'Hides target related frames.'
end

function mod:GetOptions()
	return options
end